@@ -29,7 +29,8 @@
 }
 
 
-# all valid "type" arguments for each model class
+# all valid "type" arguments for each model class.
+# Run "marginaleffects:::type_dictionary_build()" to update this list
 .typedic <- data.frame(
   class = c(
     "bam", "bam", "bart", "bart", "betareg", "betareg", "betareg",
@@ -67,29 +68,29 @@
     "quantile", "variance", "response", "link", "probs", "response",
     "link", "response", "link", "prediction", "average", "probs",
     "class", "prob", "cum.prob", "linear.predictor", "expected",
-    "lp", "risk", "survival", "expected", "lp", "risk", "survival",
-    "expected", "lp", "risk", "survival", "response", "location",
+    "lp", "risk", "survival", "survival", "expected", "lp", "risk",
+    "survival", "expected", "lp", "risk", "response", "location",
     "scale", "density", "pr", "xb", "location", "cumprob", "scale",
-    "density", "pr", "xb", "response", "mean", "link", "lp", "linear",
-    "rmst", "survival", "hazard", "cumhaz", "invlink(link)", "response",
-    "link", "response", "prob", "count", "zero", "response", "response",
-    "response", "link", "invlink(link)", "response", "link", "response",
-    "link", "lp", "response", "link", "invlink(link)", "response",
-    "link", "response", "link", "response", "response", "link", "response",
-    "link", "conditional", "zprob", "zlink", "disp", "response",
-    "link", "response", "invlink(link)", "probs", "response", "lp",
-    "link", "response", "response", "response", "response", "response",
-    "fitted", "lp", "mean", "response", "latent", "link", "response",
-    "latent", "link", "response", "numeric", "prob", "class", "numeric",
-    "prob", "class", "probs", "latent", "probs", "response", "mean",
-    "E", "Ep", "p", "response", "response", "link", "expected", "detection",
-    "latent_N", "invlink(link)", "response", "link", "lp", "probability",
-    "utility", "fitted", "mean", "lp", "probs", "response", "link",
-    "lp", "mean", "probs", "response", "link", "response", "response",
-    "link", "unconditional", "response", "response", "link", "response",
-    "link", "response", "link", "quantile", "response", "link", "probs",
-    "response", "expvalue", "linpred", "prob", "response", "prob",
-    "count", "zero"
+    "density", "pr", "xb", "survival", "response", "mean", "link",
+    "lp", "linear", "rmst", "hazard", "cumhaz", "invlink(link)",
+    "response", "link", "response", "prob", "count", "zero", "response",
+    "response", "response", "link", "invlink(link)", "response",
+    "link", "response", "link", "lp", "response", "link", "invlink(link)",
+    "response", "link", "response", "link", "response", "response",
+    "link", "response", "link", "conditional", "zprob", "zlink",
+    "disp", "response", "link", "response", "invlink(link)", "probs",
+    "response", "lp", "link", "response", "response", "response",
+    "response", "response", "fitted", "lp", "mean", "response", "latent",
+    "link", "response", "latent", "link", "response", "numeric",
+    "prob", "class", "numeric", "prob", "class", "probs", "latent",
+    "probs", "response", "mean", "E", "Ep", "p", "response", "response",
+    "link", "expected", "detection", "latent_N", "invlink(link)",
+    "response", "link", "lp", "probability", "utility", "fitted",
+    "mean", "lp", "probs", "response", "link", "lp", "mean", "probs",
+    "response", "link", "response", "response", "link", "unconditional",
+    "response", "response", "link", "response", "link", "response",
+    "link", "quantile", "response", "link", "probs", "response",
+    "expvalue", "linpred", "prob", "response", "prob", "count", "zero"
   ),
   stringsAsFactors = FALSE
 )
@@ -97,32 +98,40 @@
 
 # the default "type" arguments for each model class. Used to set the
 # default type in "ggaverage()"
+# Run following code to update this list:
+# x <- marginaleffects:::type_dictionary_build()
+# x[!duplicated(x$class), ]
+# Finally, add "other" as first element to "class" and "response" to "type"
 .default_type <- data.frame(
   class = c(
-    "other", "bam", "bart", "betareg", "bife",
-    "bracl", "brglmFit", "brmsfit", "brmultinom", "clm", "clogit",
-    "coxph", "crch", "hetprob", "hxlr", "ivpml", "fixest", "hurdle",
-    "iv_robust", "lm", "gam", "Gam", "geeglm", "Gls", "glimML", "glm",
-    "glmerMod", "glmrob", "glmmTMB", "glmmPQL", "glmx", "ivreg",
-    "lmerMod", "lmerModLmerTest", "lmrob", "lm_robust", "lrm", "mblogit",
-    "mclogit", "MCMCglmm", "model_fit", "workflow", "multinom", "mhurdle",
-    "mlogit", "mvgam", "negbin", "ols", "oohbchoice", "orm", "polr",
-    "rlm", "selection", "speedlm", "speedglm", "stanreg", "survreg",
-    "svyglm", "svyolr", "tobit", "tobit1", "zeroinfl"
+    "other",
+    "bam", "bart", "betareg", "bife", "bracl",
+    "brglmFit", "brmsfit", "brmultinom", "clm", "clogit", "coxph",
+    "coxph_weightit", "crch", "hetprob", "hxlr", "ivpml", "flexsurvreg",
+    "fixest", "hurdle", "iv_robust", "lm", "gam", "Gam", "geeglm",
+    "Gls", "glimML", "glm", "glmerMod", "glmgee", "glmrob", "glmmTMB",
+    "glmmPQL", "glmx", "glm_weightit", "ivreg", "lmerMod", "lmerModLmerTest",
+    "lmrob", "lm_robust", "lrm", "mblogit", "mclogit", "MCMCglmm",
+    "model_fit", "workflow", "multinom", "multinom_weightit", "mhurdle",
+    "mlogit", "mvgam", "negbin", "ols", "oohbchoice", "orm", "ordinal_weightit",
+    "polr", "rendo.base", "rlm", "selection", "speedlm", "speedglm",
+    "stanreg", "survreg", "svyglm", "svyolr", "tobit", "tobit1",
+    "zeroinfl"
   ),
   type = c(
     "response",
-    "response", "ev", "response", "response", "probs", "response",
-    "response", "probs", "prob", "expected", "expected", "response",
-    "pr", "location", "pr", "invlink(link)", "response", "response",
-    "response", "response", "invlink(link)", "response", "lp", "response",
+    "response", "ev", "response", "response",
+    "probs", "response", "response", "probs", "prob", "expected",
+    "survival", "survival", "response", "pr", "location", "pr", "survival",
     "invlink(link)", "response", "response", "response", "response",
+    "invlink(link)", "response", "lp", "response", "invlink(link)",
     "response", "response", "response", "response", "response", "response",
-    "fitted", "response", "response", "response", "numeric", "numeric",
-    "probs", "E", "response", "response", "invlink(link)", "lp",
-    "probability", "fitted", "probs", "response", "response", "response",
-    "response", "response", "response", "response", "probs", "response",
-    "expvalue", "response"
+    "invlink(link)", "response", "response", "response", "response",
+    "response", "fitted", "response", "response", "response", "numeric",
+    "numeric", "probs", "probs", "E", "response", "response", "invlink(link)",
+    "lp", "probability", "fitted", "probs", "probs", "response",
+    "response", "response", "response", "response", "response", "response",
+    "response", "probs", "response", "expvalue", "response"
   ),
   stringsAsFactors = FALSE
 )
